@@ -13,7 +13,7 @@
 ##############################################################################
 """Bootstrap code for principal annotation utility.
 
-$Id: bootstrap.py 97701 2009-03-09 15:10:31Z nadako $
+$Id: bootstrap.py 98693 2009-03-31 18:03:43Z icemac $
 """
 
 import transaction
@@ -32,8 +32,7 @@ def bootStrapSubscriber(event):
     db, connection, root, root_folder = getInformationFromEvent(event)
 
     ensureUtility(root_folder, IPrincipalAnnotationUtility,
-                  'PrincipalAnnotation', PrincipalAnnotationUtility,
-                  asObject=True)
+                  'PrincipalAnnotation', PrincipalAnnotationUtility)
 
     transaction.commit()
     connection.close()
